pub struct OperationDescriptor<'h> { /* private fields */ }Expand description
An un-compiled operation descriptor. Users typically create these
through constructors on Contraction, Reduction,
ElementwiseBinary, ElementwiseTrinary, or Permutation.
Implementations
Sourceimpl<'h> OperationDescriptor<'h>
impl<'h> OperationDescriptor<'h>
Sourcepub fn as_raw(&self) -> cutensorOperationDescriptor_t
pub fn as_raw(&self) -> cutensorOperationDescriptor_t
Raw cutensorOperationDescriptor_t. Use with care.
Sourcepub fn estimate_workspace(
&self,
pref: &PlanPreference<'h>,
kind: WorkspaceKind,
) -> Result<u64>
pub fn estimate_workspace( &self, pref: &PlanPreference<'h>, kind: WorkspaceKind, ) -> Result<u64>
Estimate the scratch workspace required by a plan built from
this descriptor + pref.
Sourcepub fn estimate_runtime(
&self,
pref: &PlanPreference<'h>,
algo: i32,
) -> Result<f32>
pub fn estimate_runtime( &self, pref: &PlanPreference<'h>, algo: i32, ) -> Result<f32>
Estimated runtime in milliseconds for this op at the given
algorithm (cutensorAlgo::DEFAULT for auto).